"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getWorkshopCalendarLink = exports.createCalendarLink = void 0;

var _luxon = require("luxon");

var ADD_EVENT_ID = 'aypbtNBcPzBIdDvukmvT46093';
var TIMEZONE = 'Europe/Amsterdam';

var createDateTime = function createDateTime(isoDateWithoutTime, time) {
  var d = new Date(isoDateWithoutTime); // get date always in original time zone

  d.setTime(d.getTime() + d.getTimezoneOffset() * 60 * 1000);
  var yyyy = d.getFullYear();
  var mm = d.getMonth() + 1;
  var dd = d.getDate();
  return "".concat(yyyy, "-").concat(mm, "-").concat(dd).concat(time ? " ".concat(time) : '');
};

var createEventTitle = function createEventTitle(speaker, eventName) {
  try {
    return "".concat(speaker.name || '').concat(speaker.name ? ' - ' : '', "\"").concat(title, "\"").concat(eventName ? " at ".concat(eventName) : '');
  } catch (err) {
    return eventName;
  }
};

var createCalendarLink = function createCalendarLink(speaker, _ref) {
  var calendarEventDescription = _ref.calendarEventDescription,
      calendarEventName = _ref.calendarEventName,
      conferenceStart = _ref.conferenceStart,
      conferenceEnd = _ref.conferenceEnd;

  try {
    var talk = speaker.activities && speaker.activities.talks[0];

    var _title = createEventTitle(speaker, calendarEventName);

    var localDate = _luxon.DateTime.fromISO(talk.isoDate);

    return "https://www.addevent.com/dir/?client=".concat(ADD_EVENT_ID, "&start=").concat(localDate.toFormat('yyyy/MM/dd HH:mm'), "&duration=").concat(talk.duration, "&title=").concat(_title).concat(calendarEventDescription ? "&description=".concat(calendarEventDescription) : '', "&timezone=").concat(localDate.zoneName, "&alarm=15");
  } catch (err) {
    // Fallback whole day event
    if (calendarEventName && conferenceStart && conferenceEnd) {
      return "https://www.addevent.com/dir/?client=".concat(ADD_EVENT_ID, "&start=").concat(conferenceStart, "&end=").concat(conferenceEnd, "&title=").concat(calendarEventName).concat(calendarEventDescription ? "&description=".concat(calendarEventDescription) : '', "&timezone=Europe/London&all_day_event=true");
    }

    return null;
  }
};

exports.createCalendarLink = createCalendarLink;

var getWorkshopCalendarLink = function getWorkshopCalendarLink(_ref2, calendarEventDescription) {
  var title = _ref2.title,
      isoDate = _ref2.isoDate,
      duration = _ref2.duration;
  return "https://www.addevent.com/dir/?client=".concat(ADD_EVENT_ID, "&start=").concat(isoDate, "&duration=").concat(duration * 60, "&title=").concat(title).concat(calendarEventDescription ? "&description=".concat(calendarEventDescription) : '', "&timezone=Europe/London&alarm=15");
};

exports.getWorkshopCalendarLink = getWorkshopCalendarLink;